@@ -39,7 +39,7 @@ agent.
 
 
 
-our $VERSION = 'v0.46.1';
+our $VERSION = 'v0.46.2';
 
 use English;
 
@@ -231,7 +231,7 @@ has _json_encoder => (
 );
 
 sub _build__json_encoder {
-    JSON()->new->utf8->canonical->pretty->convert_blessed()
+    JSON()->new->utf8->canonical->pretty->allow_bignum
 }
 #
 # I just love readable and consistant JSONs
